@@ -1,7 +1,9 @@
-#include "mobilehotspotconfiguration.h"
-#include "accesspointgui.h"
 #include <QtGui/QDialog>
 #include <QtGui/QMessageBox>
+#include <QtCore/QString>
+#include "mobilehotspotconfiguration.h"
+#include "accesspointgui.h"
+
 
 AccessPointGUI::AccessPointGUI(QWidget *parent)
     : QDialog(parent)
@@ -15,16 +17,18 @@ AccessPointGUI::~AccessPointGUI()
 }
 
 void AccessPointGUI::setConfiguration(MobileHotspotConfiguration &configuration){
-	ui.txtAPName->setText(configuration.apname);
-	ui.chkEncryption->setChecked(configuration.encryption == configuration.ENCRYPTION_WEP);
-	ui.txtKey->setText(configuration.key);
+	ui.txtAPName->setText(configuration.hotspotName);
+	ui.chkEncryption->setChecked(configuration.encryptionType == configuration.ENCRYPTION_WEP);
+	ui.txtKey->setText(configuration.encryptionKey);
+	ui.chkPower->setChecked(configuration.disablePowerSaving);
 }
 
-void AccessPointGUI::getConfiguration(MobileHotspotConfiguration *configuration){
+void AccessPointGUI::configuration(MobileHotspotConfiguration *configuration){
 	QString name = ui.txtAPName->text().replace("\\", "").replace("\"", "");
-	configuration->apname = name == "" ? "N900 Hotspot" : name;
-	configuration->encryption = ui.chkEncryption->isChecked() ? configuration->ENCRYPTION_WEP : configuration->ENCRYPTION_NONE;
-	configuration->key = validKey();
+	configuration->hotspotName = name == "" ? "N900 Hotspot" : name;
+	configuration->encryptionType = ui.chkEncryption->isChecked() ? configuration->ENCRYPTION_WEP : configuration->ENCRYPTION_NONE;
+	configuration->encryptionKey = validKey();
+	configuration->disablePowerSaving = ui.chkPower->isChecked();
 }
 
 QString AccessPointGUI::validKey(){
