@@ -21,12 +21,9 @@ HotspotHelper::~HotspotHelper(){
 }
 
 int HotspotHelper::loadSystemModules(QStringList *alreadyLoadedModules){
-	/* 0=ok, 1=fail */
+	/* 0=ok, -1=fail */
 	qDebug("** Loading system modules **");
 	int result = 0, cmdret;
-	QString unamer;
-	CommandHelper::executeCommandWithStdOut("uname -r", &cmdret, &unamer);
-	unamer = unamer.left(unamer.size() - 1); // stdout adds a \n after the answer, we remove it
 	QStringList mods = getSystemModules();
 	QString loadedModules;
 	CommandHelper::executeCommandWithStdOut("lsmod", &cmdret, &loadedModules);
@@ -39,10 +36,10 @@ int HotspotHelper::loadSystemModules(QStringList *alreadyLoadedModules){
 		}
 		else{
 			qDebug( (QString("Loading ") + mod).toAscii().data() );
-			int ret = loadModule(mod, unamer);
+			int ret = loadModule(mod);
 			if(ret != 0){
 				qDebug( (QString("FAILURE WHEN LOADING ") + mod).toAscii().data());
-				result = 1;
+				result = -1;
 			}
 		}
 	}
@@ -55,15 +52,15 @@ QStringList HotspotHelper::getSystemModules(){
 	return list;
 }
 
-int HotspotHelper::loadModule(QString moduleName, QString unamer){
+int HotspotHelper::loadModule(QString moduleName){
 	/* 0=ok, -1=fail */
-	QString cmd("insmod /lib/modules/"); cmd += unamer; cmd += "/";
-	cmd += moduleName; cmd += ".ko";
-	return CommandHelper::executeCommand(cmd) ? 0 : -1;
+	QString cmd("modprobe ");
+	cmd += moduleName;
+	return CommandHelper::executeCommandOld(cmd) == 0 ? 0 : -1;
 }
 
 int HotspotHelper::unloadSystemModules(QStringList &alreadyLoadedModules){
-	/* 0=ok, 1=fail */
+	/* 0=ok, -1=fail */
 	qDebug("** Unloading system modules **");
 	int result = 0;
 	QStringList mods = getSystemModules();
@@ -78,7 +75,7 @@ int HotspotHelper::unloadSystemModules(QStringList &alreadyLoadedModules){
 			int ret = unloadModule(mod);
 			if(ret != 0){
 				qDebug( (QString("FAILURE WHEN UNLOADING ") + mod).toAscii().data());
-				result = 1;
+				result = -1;
 			}
 		}
 	}
@@ -88,7 +85,7 @@ int HotspotHelper::unloadSystemModules(QStringList &alreadyLoadedModules){
 int HotspotHelper::unloadModule(QString moduleName){
 	/* 0=ok, -1=fail */
 	QString cmd("rmmod "); 	cmd += moduleName;
-	return CommandHelper::executeCommand(cmd) ? 0 : 1;
+	return CommandHelper::executeCommandOld(cmd) == 0 ? 0 : -1;
 }
 
 int HotspotHelper::disableInternetConnection(MobileHotspotConfiguration &configuration){
@@ -155,6 +152,17 @@ int HotspotHelper::prepareUSBInterface(MobileHotspotConfiguration &configuration
 	else if(ret != 0)
 		qDebug("WARNING :  Was not able to disable the USB interface");
 
+	/** Change USB MAC if necessary **/
+	if(configuration.usbMAC != ""){
+		ret = setUSBMAC(configuration);
+		if(ret == -2){
+			qDebug("Error (timeout) while changing the USB MAC");
+			return -1;
+		}
+		else if(ret != 0)
+			qDebug("WARNING : Was not able to change the USB MAC");
+	}
+
 	/** Enable USB interface **/
 	ret = enableUSBInterface(configuration);
 	if(ret != 0){
@@ -165,18 +173,91 @@ int HotspotHelper::prepareUSBInterface(MobileHotspotConfiguration &configuration
 	return 0;
 }
 
+int HotspotHelper::setUSBMAC(MobileHotspotConfiguration &configuration){
+	/* -1=fail, -2=timeout, 0=ok */
+	qDebug("*** Changing USB MAC ***");
+	int ret, tries;
+	bool cmdret, trying;
+	QString cmd("/sbin/ifconfig "); cmd += configuration.INTERFACE_USB; cmd += " hw ether "; cmd += configuration.usbMAC;
+	cmdret = CommandHelper::executeCommand(cmd, &ret);
+	if( (! cmdret) || (cmdret && ret != 0) ){
+		qDebug("FAILURE : Cannot change USB MAC");
+		return -1;
+	}
+	trying = true; tries = 0;
+	while(trying && tries < MAX_TRIES){
+		tries++;
+		QString res;
+		CommandHelper::executeCommandWithStdOut(QString("/sbin/ifconfig ") + configuration.INTERFACE_USB, &ret, &res);
+		if(res.toLower().count(configuration.usbMAC.toLower()) > 0)
+			trying = false;
+		else
+			CommandHelper::executeCommand("sleep 1");
+	}
+	if(trying){
+		qDebug("FAILURE : System was too slow changing USB MAC");
+		return -2;
+	}
+	return 0;
+}
+
+
 int HotspotHelper::checkUSBMode(){
 	/* -1=fail, 0=ok */
 	qDebug("** Checking USB mode **");
 	QString res; int cmdret;
 	CommandHelper::executeCommandWithStdOut("cat /proc/driver/musb_hdrc", &cmdret, &res);
-	if(res.count("g_nokia") < 1){
-		qDebug("FAILURE : USB must be in PC-Suite Mode");
+	res = res.toLower();
+	if(res.count("gadget driver: (none)") < 1 ){
+		qDebug("FAILURE : USB should be free of any module (=no USB-mode) but it is still used");
 		return -1;
 	}
 	return 0;
 }
 
+int HotspotHelper::loadStandardUSB(){
+	/* -1=fail, 0=ok */
+	qDebug("** Loading g_ether **");
+	int ret;
+	ret = loadModule("g_ether");
+	if(ret != 0){
+		qDebug("WARNING : Was not able to load g_ether, it is supposed to be provided by recents power-kernels (>=v46)");
+		return -1;
+	}
+	return 0;
+}
+
+void HotspotHelper::unloadStandardUSB(){
+	qDebug("** Unloading g_ether **");
+	int ret;
+	ret = unloadModule("g_ether");
+	if(ret != 0)
+		qDebug("WARNING : Was not able to unload g_ether");
+}
+
+int HotspotHelper::loadNokiaUSB(){
+	/* -1=fail, 0=ok */
+	qDebug("** Loading g_nokia **");
+	int ret;
+	ret = loadModule("g_nokia");
+	if(ret != 0){
+		qDebug("WARNING : Was not able to load g_nokia");
+		return -1;
+	}
+	return 0;
+}
+
+void HotspotHelper::unloadNokiaUSB(){
+	qDebug("** Unloading g_nokia & g_file_storage **");
+	int ret;
+	ret = unloadModule("g_nokia");
+	if(ret != 0)
+		qDebug("WARNING : Was not able to unload g_nokia");
+	ret = unloadModule("g_file_storage");
+	if(ret != 0)
+		qDebug("WARNING : Was not able to unload g_file_storage");
+}
+
 int HotspotHelper::disableUSBInterface(MobileHotspotConfiguration &configuration){
 	/* -1=fail, -2=timeout, 0=ok */
 	qDebug("** Disabling USB interface **");
