@@ -8,7 +8,7 @@
 
 
 #define MAX_TRIES (15)
-#define SYSTEM_MODULES "nf_conntrack, nf_defrag_ipv4, nf_conntrack_ipv4, x_tables, ip_tables, nf_nat, iptable_nat, ipt_MASQUERADE" // Credits to Rambo
+#define SYSTEM_MODULES "nf_conntrack, nf_defrag_ipv4, nf_conntrack_ipv4, x_tables, xt_mac, ip_tables, iptable_mangle, iptable_filter, nf_nat, iptable_nat, ipt_MASQUERADE" // Credits to Rambo
 
 
 class HotspotHelper
@@ -22,6 +22,10 @@ public:
     static int disableInternetConnection(MobileHotspotConfiguration &configuration);
     static int enableInternetConnection(MobileHotspotConfiguration &configuration);
     static int checkUSBMode();
+    static int loadStandardUSB();
+    static void unloadStandardUSB();
+    static int loadNokiaUSB();
+    static void unloadNokiaUSB();
     static int prepareUSBInterface(MobileHotspotConfiguration &configuration);
     static int prepareWifiInterface(MobileHotspotConfiguration &configuration);
     static int unprepareUSBInterface(MobileHotspotConfiguration &configuration);
@@ -32,10 +36,11 @@ public:
     static int unsetIPTables(MobileHotspotConfiguration &configuration, int ipforward);
 
 private:
-	static int loadModule(QString moduleName, QString unamer);
+	static int loadModule(QString moduleName);
 	static int unloadModule(QString moduleName);
 	static QStringList getSystemModules();
 	static int enableUSBInterface(MobileHotspotConfiguration &configuration);
+	static int setUSBMAC(MobileHotspotConfiguration &configuration);
 	static int disableUSBInterface(MobileHotspotConfiguration &configuration);
 	static int enableWifiInterface(MobileHotspotConfiguration &configuration);
 	static int disableWifiInterface(MobileHotspotConfiguration &configuration);
