@@ -14,7 +14,7 @@ public:
     InternetAccessGUI(QWidget *parent = 0);
     ~InternetAccessGUI();
     void setConfiguration(MobileHotspotConfiguration &configuration);
-    void getConfiguration(MobileHotspotConfiguration *configuration);
+    void configuration(MobileHotspotConfiguration *configuration);
 
 private:
     Ui::InternetAccessGUIClass ui;
