@@ -1,5 +1,8 @@
 #include <QtCore/QObject>
 #include <QtCore/QString>
+#include <QtCore/QDateTime>
+#include <QtCore/QFile>
+#include <QtCore/QIODevice>
 #include <gq/gconfitem.h>
 #include "dbushelper.h"
 #include "apnhelper.h"
@@ -74,6 +77,23 @@ void MobileHotspotConfiguration::load(){
 	else
 		enforcement2g3g = IGNORE;
 	delete item;
+
+	loadUSBMAC();
+}
+
+QString MobileHotspotConfiguration::newMAC(){
+	QString result("02:");
+	qsrand(QDateTime::currentDateTime().toTime_t());
+	for(int i = 0; i < 5; i++){
+		if(i > 0)
+			result += ":";
+		int number1 = qrand() % 16;
+		int number2 = qrand() % 16;
+		result += QString("%1").arg(number1, 0, 16);
+		result += QString("%1").arg(number2, 0, 16);
+	}
+	result = result.toLower();
+	return result;
 }
 
 void MobileHotspotConfiguration::save(){
@@ -129,6 +149,8 @@ void MobileHotspotConfiguration::save(){
 	else
 		item->set("ignore");
 	delete item;
+
+	saveUSBMAC();
 }
 
 QString MobileHotspotConfiguration::internetInterface() const{
@@ -137,3 +159,31 @@ QString MobileHotspotConfiguration::internetInterface() const{
 	else
 		return INTERFACE_GPRS;
 }
+
+void MobileHotspotConfiguration::loadUSBMAC(){
+	QFile file(FILE_USBMAC);
+	try{
+		if(! file.open(QIODevice::ReadOnly | QIODevice::Text))
+			throw (QString("Cannot open file ") + FILE_USBMAC);
+		usbMAC = QString(file.readAll()).trimmed();
+		file.close();
+	}
+	catch(QString fail){
+		qDebug("WARNING : Was not able to load the USB MAC address (%s), using a new one", fail.toAscii().data());
+		usbMAC = newMAC();
+		saveUSBMAC();
+	}
+}
+
+void MobileHotspotConfiguration::saveUSBMAC(){
+	QFile file(FILE_USBMAC);
+	try{
+		if(! file.open(QIODevice::WriteOnly | QIODevice::Truncate | QIODevice::Text))
+			throw (QString("Cannot open file ") + FILE_USBMAC);
+		file.write(usbMAC.toAscii());
+		file.close();
+	}
+	catch(QString fail){
+		qDebug("WARNING : Was not able to save the USB MAC address (%s)", fail.toAscii().data());
+	}
+}
