@@ -18,6 +18,7 @@
 #define GCONF_NETWORK GCONF "/network"
 #define GCONF_INTERNET GCONF "/internet"
 #define GCONF_2G3G	GCONF "/2g3g"
+#define FILE_USBMAC "/home/user/.qtmobilehotspot/usb.mac"
 
 
 enum Enforcement{
@@ -39,7 +40,7 @@ public:
 	static const QString INTERFACE_USB;
 	static const QString INTERFACE_GPRS;
 
-	QString hotspotName, encryptionType, encryptionKey, lanInterface, lanNetwork, internetAPName, internetAPType, internetAPID;
+	QString hotspotName, encryptionType, encryptionKey, lanInterface, lanNetwork, internetAPName, internetAPType, internetAPID, usbMAC;
 	bool internetEnabled, disablePowerSaving;
 	Enforcement enforcement2g3g;
 
@@ -49,6 +50,11 @@ public:
     void load();
     void save();
     QString internetInterface() const;
+
+private:
+	QString newMAC();
+	void saveUSBMAC();
+	void loadUSBMAC();
 };
 
 #endif // MOBILEHOTSPOTCONFIGURATION_H
