@@ -138,15 +138,6 @@ void MobileHotspotGUI::pluginTriggered(){
 	qApp->removeTranslator(plugin->translator());
 }
 
-void MobileHotspotGUI::about(){
-	QString message("== "); message += QApplication::applicationName(); message += " ==\n";
-	message += tr("Developped by"); message += " Loic Burtin (dest)\n";
-	message += tr("Some elements are inspired from MobileHotSpot by"); message += " Eero af Heurlin (Rambo)\n\n";
-	message += tr("This program allows your N900 to be used as a hotspot."); message += " ";
-	message += tr("Share your data connection with your other devices !");
-	QMessageBox::information(this, tr("About this program..."), message);
-}
-
 void MobileHotspotGUI::updateDisplayedConfiguration(){
 	ui.lstAccessPoint->clear();
 	ui.lstAccessPoint->addItem(configuration.hotspotName);
@@ -178,6 +169,103 @@ void MobileHotspotGUI::updateDisplayedConfiguration(){
 	ui.lstInterfaces->setCurrentIndex(configuration.lanInterface == configuration.INTERFACE_WLAN ? 0 : 1);
 }
 
+void MobileHotspotGUI::usbWindowsAssistant(){
+	QString title = tr("USB For Windows Setup");
+	bool failed = false;
+	QString text;
+	QString interface = configuration.lanInterface;
+	configuration.lanInterface = configuration.INTERFACE_USB;
+
+	try{
+		text = tr("This will help you into installing the USB networking driver into Windows. Please disconnect your N900 from your computer before continuing.");
+		if(QMessageBox::question(this, title, text, QMessageBox::Yes | QMessageBox::Cancel) != QMessageBox::Yes)
+			throw QString();
+
+		text = tr("First, ensure that you have copied the windows-usb-driver folder from /opt/qtmobilehotspot/docs (or QtMobileHotspot-Driver when connected in mass-storage mode) to your computer. If this is not the case, stop this assistant, and copy the folder.");
+		if(QMessageBox::question(this, title, text, QMessageBox::Yes | QMessageBox::Cancel) != QMessageBox::Yes)
+			throw QString();
+
+		text = tr("We are now going to unload every USB module and load the one for USB networking. Ensure that you are disconnected from your PC and that your N900 isn't in any USB mode (no PC-Suite, no mass-storage).");
+		if(QMessageBox::question(this, title, text, QMessageBox::Yes | QMessageBox::Cancel) != QMessageBox::Yes)
+			throw QString();
+
+		HotspotHelper::unloadStandardUSB();
+		HotspotHelper::unloadNokiaUSB();
+		if(HotspotHelper::checkUSBMode() != 0){
+			text = tr("It seems that the USB device is busy. Usually it is due to a USB-mode being active (mass storage / pc-suite). Please stop this mode and try again.");
+			QMessageBox::critical(this, title, text);
+			throw QString();
+		}
+		if(HotspotHelper::loadStandardUSB() != 0){
+			text = tr("The system failed to load the standard g_ether USB module. It may be due to a missing power-kernel or to a system in an inconsistent state. Please try again later.");
+			QMessageBox::critical(this, title, text);
+			throw QString();
+		}
+		if(HotspotHelper::prepareUSBInterface(configuration) != 0){
+			text = tr("The system failed to turn on the USB interface. It may be due to a system in an inconsistent state, please try again later.");
+			QMessageBox::critical(this, title, text);
+			throw QString();
+		}
+
+		text = tr("Everything seems to be fine on your N900. You can now connect it to your computer, then continue. Do not select any USB-mode when asked.");
+		if(QMessageBox::question(this, title, text, QMessageBox::Yes | QMessageBox::Cancel) != QMessageBox::Yes)
+			throw QString();
+
+		text = tr("Are you running Windows 7 / Windows Vista ?");
+		if(QMessageBox::question(this, title, text, QMessageBox::Yes | QMessageBox::No) != QMessageBox::Yes){
+			text = tr("The computer will ask you about drivers. Tell it that you want to do an expert install (pick the driver yourself).");
+			if(QMessageBox::question(this, title, text, QMessageBox::Yes | QMessageBox::Cancel) != QMessageBox::Yes)
+				throw QString();
+
+			text = tr("Now edit the settings in order to make Windows use your windows-usb-driver folder. Make sure not to forget any useful checkbox.");
+			if(QMessageBox::question(this, title, text, QMessageBox::Yes | QMessageBox::Cancel) != QMessageBox::Yes)
+				throw QString();
+		}
+		else{
+			text = tr("The computer will try to install a driver automatically (usually). It will fail, that is normal.");
+			if(QMessageBox::question(this, title, text, QMessageBox::Yes | QMessageBox::Cancel) != QMessageBox::Yes)
+				throw QString();
+
+			text = tr("Now go to the device manager (control panel, system, device manager). You should see an unknown device called Linux Ethernet RNDIS. Right-click on it, and choose Update driver.");
+			if(QMessageBox::question(this, title, text, QMessageBox::Yes | QMessageBox::Cancel) != QMessageBox::Yes)
+				throw QString();
+
+			text = tr("Choose to pick the driver yourself, and tell the program about your windows-usb-driver folder. Do not miss any important checkbox.");
+			if(QMessageBox::question(this, title, text, QMessageBox::Yes | QMessageBox::Cancel) != QMessageBox::Yes)
+				throw QString();
+		}
+
+		text = tr("Your computer will now install the USB networking driver. If everything goes fine, congratulations, you have a new network device available in the devices-list.");
+		if(QMessageBox::question(this, title, text, QMessageBox::Yes | QMessageBox::Cancel) != QMessageBox::Yes)
+			throw QString();
+
+		text = tr("You are now ready to use the program in USB mode with your Windows. Just remember to never use pc-suite/mass-storage modes when you enable USB networking.");
+		if(QMessageBox::question(this, title, text, QMessageBox::Yes | QMessageBox::Cancel) != QMessageBox::Yes)
+			throw QString();
+
+		text = tr("Windows should not need more configuration in order to be used with qtmobilehotspot. Simply run qtmobilehotspot, start in USB mode, plug your N900 into your PC, and enjoy.");
+		if(QMessageBox::question(this, title, text, QMessageBox::Yes | QMessageBox::Cancel) != QMessageBox::Yes)
+			throw QString();
+
+		text = tr("Please note that if you are already using MADDE on your computer, you may have to reset your new network card settings to automatic.");
+		if(QMessageBox::question(this, title, text, QMessageBox::Yes | QMessageBox::Cancel) != QMessageBox::Yes)
+			throw QString();
+	}
+	catch(QString fail){
+		qDebug("WARNING : Interrupted Windows USB Assistant");
+		failed = true;
+	}
+
+	text = tr("Please disconnect your N900 from your computer. We are going to unload the USB module and load the normal Nokia one. Do not choose any USB mode if you plan to use qtmobilehotspot.");
+	if(! failed)
+		QMessageBox::information(this, title, text);
+	HotspotHelper::unprepareUSBInterface(configuration);
+	HotspotHelper::unloadStandardUSB();
+	HotspotHelper::loadNokiaUSB();
+
+	configuration.lanInterface = interface;
+}
+
 void MobileHotspotGUI::configureInternetAccess(){
 	/** Find available networks **/
 	//TODO
@@ -271,7 +359,7 @@ void MobileHotspotGUI::startProcedure(){
 	if(configuration.lanInterface == configuration.INTERFACE_WLAN && configuration.internetInterface() == configuration.INTERFACE_WLAN){
 		/** Both LAN and INET are on WLAN, that is not possible **/
 		QString fail = tr("Error : LAN and Internet are both using the Wifi interface, please use a LAN on USB");
-		QMessageBox::critical(this, tr("Invalid parameters"), fail);
+		QMessageBox::critical(this, tr("Cannot start"), fail);
 		return;
 	}
 
@@ -337,10 +425,22 @@ void MobileHotspotGUI::startProcedure(){
 		/** USB vs Wifi **/
 		if(configuration.lanInterface == configuration.INTERFACE_USB){
 
-			/** USB mode **/
+			/** Unload all USB modules - May fail for some, but thats normal **/
+			HotspotHelper::unloadNokiaUSB();
+			HotspotHelper::unloadStandardUSB();
+
+			/** Check USB active module **/
 			ret = HotspotHelper::checkUSBMode();
 			if(ret != 0)
-				throw QString(tr("Error while checking USB mode, are you in PC Suite mode ?"));
+				throw QString(tr("Error : USB shouldn't be in any mode (no storage mode, no pc-suite mode)"));
+
+			/** Load standard USB module **/
+			ret = HotspotHelper::loadStandardUSB();
+			if(ret != 0)
+				throw QString(tr("Error while loading standard g_ether driver"));
+
+			/** Bypass USB-mode window **/
+			QTimer::singleShot(1, this, SLOT(bypassUSBModeWindow()));
 
 			/** Prepare USB interface **/
 			ret = HotspotHelper::prepareUSBInterface(configuration);
@@ -417,6 +517,7 @@ void MobileHotspotGUI::startProcedure(){
 		ui.lstInterfaces->setEnabled(false);
 		ui.btnStart->setEnabled(false);
 		ui.btnStop->setEnabled(true);
+		ui.actionUSBAssistant->setEnabled(false);
 		qDebug("*** STARTING PROCESS TERMINATED SUCCESSFULLY ***");
 	}
 	else{
@@ -471,6 +572,25 @@ void MobileHotspotGUI::stopProcedure(){
 			qDebug("Error while unpreparing USB interface");
 			success = false;
 		}
+
+		/** Unload all USB modules - May fail for some, but thats normal **/
+		HotspotHelper::unloadNokiaUSB();
+		HotspotHelper::unloadStandardUSB();
+
+		/** Check USB active module **/
+		ret = HotspotHelper::checkUSBMode();
+		if(ret != 0){
+			qDebug("Error while checking usb active modules (should be none, but thats not the case)");
+			success = false;
+		}
+
+		/** Load Nokias USB module **/
+		ret = HotspotHelper::loadNokiaUSB();
+		if(ret != 0){
+			qDebug("Error while loading Nokia USB module");
+			success = false;
+		}
+
 	}
 	else{
 
@@ -535,7 +655,7 @@ void MobileHotspotGUI::stopProcedure(){
 	ret = HotspotHelper::unloadSystemModules(alreadyLoadedModules);
 	if(ret != 0){
 		qDebug("Error while unloading system modules");
-		success = false;
+		// not that critical, no need for a message about this
 	}
 
 
@@ -568,6 +688,7 @@ void MobileHotspotGUI::stopProcedure(){
 	ui.lstInterfaces->setEnabled(true);
 	ui.btnStart->setEnabled(true);
 	ui.btnStop->setEnabled(false);
+	ui.actionUSBAssistant->setEnabled(true);
 
 	updateDisplayedConfiguration();
 	qDebug("*** STOPPING PROCESS FINISHED ***");
@@ -603,3 +724,7 @@ void MobileHotspotGUI::previousConnectionRequest(){
 	QDBusMessage msg = QDBusMessage::createMethodCall("com.nokia.icd2", "/com/nokia/icd2", "com.nokia.icd2", "state_req");
 	dbus.send(msg);
 }
+
+void MobileHotspotGUI::bypassUSBModeWindow(){
+	//TODO
+}
