@@ -63,16 +63,17 @@ protected :
         void closeEvent(QCloseEvent* event);
 
 private slots:
+	void usbWindowsAssistant();
 	void configureAccessPoint();
 	void configureInternetAccess();
 	void doConfigureInternetAccess();
 	void configureInterface(int index);
 	void pluginTriggered();
-	void about();
 	void start(bool notification = true);
 	void startProcedure();
 	void stop(bool notification = true);
 	void stopProcedure();
+	void bypassUSBModeWindow();
 	void previousConnectionSignal(const QDBusMessage &message);
 	void availableAPNsSignal(const QDBusMessage &message);
 };
